%generateScript: simulates the trajectory of the robot using square
%                path given by generate motion
%
%data=generateScript(initialstatemean,numSteps,alphas,betas)
%     generates data of the form 
%     [realObservation', noisefreeMotion', noisefreeObservation',
%     realRobot', noisefreeRobot']
%
%realObservation and noisefreeMotion is the only data available to
%filter.  All other data for debugging/display purposes.
%
%alphas are the 4-d noise for robot motion
%beta: noise for observations
%
%right now, observation ids not based on relationship between robot and marker
%
% TODO: update generateScript so that observations are for the
% closest marker

function data = generateScript(initialstatemean, numSteps, alphas, ...
			       beta, gamma, deltaT)

%--------------------------------------------------------------
% Initializations
%--------------------------------------------------------------

global FIELDINFO;
FIELDINFO = getfieldinfo; % retreive information about the soccer field

observationDim = 3; % observation size (bearing, marker ID)

realRobot = initialstatemean;
noisefreeRobot = initialstatemean;

for n = 1:numSteps
 % --------------------------------------------
  % Simulate motion
  % --------------------------------------------

  t=n*deltaT;
  noisefreeMotion = generateMotion(t,deltaT);
  
  % Shift real robot
  prevNoisefreeRobot = noisefreeRobot;
  noisefreeRobot = prediction( noisefreeRobot, noisefreeMotion);
  %noisefreeRobot = sampleOdometry( noisefreeMotion, noisefreeRobot, ...
  %			   [0 0 0 0]);
  
  % Move robot
  realRobot = sampleOdometry( noisefreeMotion, realRobot, alphas);
  
  %--------------------------------------------------------------
  % Simulate observation
  %--------------------------------------------------------------

  % n / 2 causes each landmark to be viewed twice
  markerId = mod( floor( n / 2), FIELDINFO.NUM_MARKERS) + 1;
  
  noisefreeObservation = observation( realRobot, FIELDINFO, markerId);

  % Observation noise
  Q = [ gamma^2  0   0;
        0       beta^2 0;
        0       0   1e-10]; %epsilon necessary for the sample function

  observationNoise = sample( zeros(observationDim,1), Q, observationDim);
  realObservation = noisefreeObservation + observationNoise;
  
  data(n,:) = [realObservation', noisefreeMotion', noisefreeObservation', realRobot', noisefreeRobot'];
end
