function run(numSteps)

%--------------------------------------------------------------
% Graphics
%--------------------------------------------------------------

NOISEFREE_PATH_COL = 'green';
REAL_PATH_COL = 'blue';

GLOBAL_FIGURE = 1;

%--------------------------------------------------------------
% Initializations
%--------------------------------------------------------------

initialstatemean = [180 50 0 ]';

% Motion noise (in odometry space, see p.134 in book). 
 alphas = [0.05 0.001 0.05 0.01];

% Standard deviation of Gaussian sensor noise (independent of distance)
beta = deg2rad(20);

% Standard deviation of Gaussian distance noise
gamma = 15;

% Step size between filter updates, can be less than 1.
deltaT=0.1;

% Generate motion and sensor info consistent with noise models.
data = generateScript(initialstatemean, numSteps, alphas, beta, gamma, deltaT);

observationDim = 3; % observation size (bearing, marker ID)

% column indices in the data matrix
idxsRO = 1:observationDim; % Real observations: (distance, angle, markerId)
idxsNFM = max(idxsRO) + [1:3]; % Noise free motion
idxsNFO = max(idxsNFM) + [1:observationDim]; % Noise free observation
idxsRR = max(idxsNFO) + [1:3]; % Real robot
idxX = idxsRR(1); % (x, y, theta) components
idxY = idxsRR(2);
idxT = idxsRR(3);
idxsNFR = max(idxsRR) + [1:3]; % Noise free robot
idxNFX = idxsNFR(1); % (x, y, theta) components
idxNFY = idxsNFR(2);
idxNFT = idxsNFR(3);

% TODO: provide proper initialization for your filters here
% You can set the initial mean and variance of the EKF to the true mean and
% some uncertainty.

% Call ekfUpdate and pfUpdate in every iteration of this loop.
% You might consider putting in a switch so you can select which
% algorithm does the update
for t = 1:numSteps

  % since we don't care about the data association problem, noisefreeObs(3)
  % and realObs(3) will always be the same
  realObs = data(t,idxsRO);
  motionCommand = data(t,idxsNFM);
  
  % real position
  x = data(t,idxX);
  y = data(t,idxY);
  theta = data(t,idxT);
  
  figure(GLOBAL_FIGURE);
  clf;
  hold on;
  plotfield(realObs(3)); % highlight observed marker
  plotrobot( x, y, theta, 'black', 1, REAL_PATH_COL);
  
  % draw real path and path that would result if there was no noise on
  % motion
  plot([initialstatemean(1) data(1,idxX)], [initialstatemean(2) data(1,idxY)], 'Color', REAL_PATH_COL);
  plot([initialstatemean(1) data(1,idxNFX)], [initialstatemean(2) data(1,idxNFY)], 'Color', NOISEFREE_PATH_COL);

  % draw real path
  plot(data(1:t,idxX), data(1:t,idxY), 'Color', REAL_PATH_COL);
  % draw noisy path
  plot(data(1:t,idxNFX), data(1:t,idxNFY), 'Color', NOISEFREE_PATH_COL);

  % indicate observed angle relative to real position
  plot([x x+cos(theta+realObs(2))*realObs(1)], [y y+sin(theta+realObs(2))*realObs(1)], 'Color', REAL_PATH_COL);

  %TODO: update the filter here

  %TODO: plot and evaluate filter results here

  axis square;
  title(sprintf('t = %d / %d', t, numSteps));
  pause(0.3);
end

